* ==============================================================================
* Date	: 24.07.2024
* Paper: Pesticide Regulatory Heterogeneity, Foreign Sourcing, and Global Agricultural Value Chains
* Author: Dela-Dem Doe Fiankor, Bernhard Dalheimer, and Gabriele Mack
* E-mail: dela-demdoe.fiankor@agroscope.admin.ch
*
* Written in Stata 17
* ==============================================================================

clear all

* First, the user must define one global macro in order to run the analysis:
global SwissMRL "O:\Data-Work\25_Agricultural_Economics-RE\255_OEMPA\01_Projekte\02_Marktanalyse\02_Non-TariffMeasures\Maximum Residue Limits" 
global SwissFirms "O:\Data-Work\25_Agricultural_Economics-RE\253_SupplyEvaluation\fide\Distance and export price variation" 
global SwissNTM "O:\Data-Work\25_Agricultural_Economics-RE\253_SupplyEvaluation\NTM\Advalorem equivalents" 


* Confirm that the globals for the project root directory has been defined. 
* If this fails then the global has not been defined properly
assert !missing("$SwissMRL") 
set more off, perm

cap mkdir "$SwissMRL/Results"
cap mkdir "$SwissMRL/Results/Figures"
cap mkdir "$SwissMRL/Results/Tables"

* Initialize log and record system parameters
clear 
log using "$SwissMRL/Results/SwissMRL.log", replace
local datetime : di %tcCCYY.NN.DD!_HH.MM.SS `=clock("$S_DATE $S_TIME", "DMYhms")'


di "Begin date and time: $S_DATE $S_TIME"
di "Stata version: `c(stata_version)'"
di "Updated as of: `c(born_date)'"
di "Variant:       `=cond( c(MP),"MP",cond(c(SE),"SE",c(flavor)) )'"
di "Processors:    `c(processors)'"
di "OS:            `c(os)' `c(osdtl)'"
di "Machine type:  `c(machine_type)'"	

* Install following packages 
	*ssc inst expgen
	*ssc inst carryforward
	*ssc inst asdoc
	*scc inst kountry
	* ssc inst xls2dta
	*ssc install aaplot
	*ssc inst egenmore
	*ssc inst texsave
	*ssc inst gtools
* Run project analysis
do "$SwissNTM/Scripts/1_DataCleaning.do"
do "$SwissMRL/Scripts/1_DataAnalysis.do"

End log
di "End date and time: $S_DATE $S_TIME"
log close

* EOF

