use "$SwissMRL/Data/mrl_data_v4",  clear

drop if mrl_codex == . 
fillin  hs8  country activ t
drop _fillin

replace mrl = mrl_codex if mrl == . & country == "ARG"
replace mrl = mrl_codex if mrl == . & country == "BRA"
replace mrl = mrl_codex if mrl == . & country == "CHL"
replace mrl = mrl_codex if mrl == . & country == "CHN"
replace mrl = mrl_codex if mrl == . & country == "EGY"
replace mrl = mrl_codex if mrl == . & country == "IND"
replace mrl = mrl_codex if mrl == . & country == "ISR"

replace mrl = 0.01 if mrl == . & country == "AUS"
replace mrl = 0.01 if mrl == . & country == "CAN"
replace mrl = 0.01 if mrl == . & country == "EU"
replace mrl = 0.01 if mrl == . & country == "JPN"
replace mrl = 0.01 if mrl == . & country == "NZL"
replace mrl = 0.01 if mrl == . & country == "NOR"
replace mrl = 0.01 if mrl == . & country == "USA"
replace mrl = 0.01 if mrl == . & country == "ARG"
replace mrl = 0.01 if mrl == . & country == "ZAF"
replace mrl = 0.01 if mrl == . & country == "ASEAN"

replace mrl_swiss = mrl if country == "EU" & mrl_swiss == . 
replace mrl_swiss = 0.01 if mrl_swiss == .

drop if mrl_codex == . 

bys	activ hs8 t: gen mrl_co  = exp((mrl_codex - mrl_swiss)/mrl_codex)
bys       hs8 t: egen mrl_cod = mean(mrl_co)
drop activ mrl_swiss mrl_codex mrl_co  mrl
duplicates drop

save "$SwissMRL/Data/mrl_data_codex", replace 

* Duplicate EU MRLS
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
use "$SwissMRL/Data/mrl_data_codex",  clear
capture drop newobs
expand 2 if country == "EU", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_codex", replace
}
drop newobs 
drop if country == "EU"
save "$SwissMRL/Data/mrl_data_codex", replace

* Duplicate GCC MRLs
foreach x in BHR ARE SAU OMN QAT KWT{
use "$SwissMRL/Data/mrl_data_codex",  clear
capture drop newobs
expand 2 if country == "GCC", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_codex", replace
}
drop newobs 
drop if country == "GCC"
destring hs8, replace
save "$SwissMRL/Data/mrl_data_codex", replace

use "$SwissMRL/Data/import_data", clear
	merge m:1 country hs8 t using "$SwissMRL/Data/mrl_data_codex", keep(3) nogen
	merge m:1 firm_uid t using "$SwissMRL/Data/export_data", keep(1 3) nogen
	gen iso_d = "CHE"
	rename country iso_o
	merge m:1 iso_o iso_d using "$SwissNTM\Data\dist_cepii",   keep(1 3) nogen
	merge m:1 iso_o iso_d t using "$SwissNTM\Data\rta_20200520", keep(1 3) nogen
	merge m:1 iso_o  t using "$SwissMRL/Data/gdp", keep(1 3) nogen
	
save "$SwissMRL/Data/mrl_data_codex", replace 

use "$SwissMRL/Data/mrl_data_codex", clear 
egen id = group( firm_uid iso_o hs8)
duplicates tag id t, gen(isdup)
drop if isdup > 0
drop isdup
xtset id t

gen double ln_v = log(v)
*gen double ln_q = log(q)
gen double ln_mfn = log(1+mfn)
	
* Generating fixed effects
	egen fpt = group(firm_uid hs8 t)
	egen fc  = group(firm_uid iso_o)
	egen ct = group(iso_o t)
	
	reghdfe ln_v  mrl_cod ln_mfn, absorb(fc ct) cluster(fpt)
	eststo main
	gen gvc = 1 if export != .
	replace gvc = 0 if gvc == .
	tab gvc, gen(gvc_) 
	gen mrl_nogvc = mrl_cod * gvc_1
	gen mrl_gvc= mrl_cod * gvc_2 

reghdfe ln_v  mrl_cod gvc mrl_gvc ln_mfn, absorb(fc ct) cluster(fpt)
eststo gvc 

* (3a) Firm sizes defined based on number of employees in the firm (Table 5)    *
* ******************************************************************************
replace firm_size = "small" if firm_size == "< 10 persons"
replace firm_size = "medium" if firm_size == "10-49 persons"
replace firm_size = "large" if firm_size == "50-249 persons"
replace firm_size = "large" if firm_size == "> 249 persons"

egen fsize_id = group(firm_uid firm_size)
bys firm_uid t: egen new = nvals( fsize_id )
	
	tab firm_size, gen(size) 
	
	gen mrl_small  = mrl_cod * size3
	gen mrl_medium = mrl_cod * size2
	gen mrl_large  = mrl_cod * size1
	
reghdfe ln_v  mrl_cod mrl_medium mrl_large  ln_mfn if new == 1, absorb(fc ct) cluster(fpt)
eststo fsize_employment

esttab main gvc fsize_employment  using "$SwissMRL/Results/Tables/TableCodex.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Main""GVC""Size") title("codex") ar2(3)  b(3) se(3) replace nogap drop(_cons) order(mrl_cod gvc mrl_gvc mrl_medium mrl_large  ln_mfn) compress
	/*

	bys hs8 t: egen double n_firms  = nvals(firm_uid ) 		// Number of importing firms
	gen double v_mean = (v / n_firms) 	// Import value per product per firm
	gen double ln_firms = log(n_firms)
	gen double ln_v_mean = log(v_mean)	

	foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_cod ln_mfn, absorb(fc ct) cluster(fpt)
	eststo `v'
}


esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableCodex.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableCodex.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress