* Empirical analysis: 
use "$SwissMRL/Data/mrl_data_v6", clear 

egen id = group( firm_uid iso_o hs8)
duplicates tag id t, gen(isdup)
drop if isdup > 0
drop isdup
xtset id t

	/*gen hs6 = int(hs8/100)
	merge m:1 iso_o hs6 t using "$SwissMRL/Data/ntm", keep(1 3)
	gen ntm = 1 if SPS != . | TBT != . | Others != . 
	replace ntm = 0 if ntm == . */

* ******************************************************************************
* (1) Baseline                                                                 *
* ******************************************************************************
gen double ln_v = log(v)
gen double ln_mfn = log(1+mfn)
egen fpt = group(firm_uid hs8 t)
egen fcp = group(firm_uid iso_o hs8)
egen ct = group(iso_o t)

reghdfe ln_v  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
eststo main

* ******************************************************************************
* (2) The role of Global Value Chains 										   *    
* ******************************************************************************
gen gvc = 1 if export != .
replace gvc = 0 if gvc == .
tab gvc, gen(gvc_) 
gen mrl_nogvc = mrl_od * gvc_1
gen mrl_gvc= mrl_od * gvc_2 

reghdfe ln_v  mrl_od gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
eststo gvc 

twoway (kdensity ln_v if  gvc == 0, lp(solid)) (kdensity ln_v if  gvc == 1), scheme(s2mono) legend(size(mediumsmall) rows(1) lab(1 "Importer only") lab(2 "Importer and exporter")) ytitle("kdensity") xtitle("Trade value in CHF (logs)") xsize(6) ysize(4)
graph export "$SwissMRL/Results/Figures/Figure2a.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/Figure2a.png", as(png) replace

preserve 
collapse(sum) v q, by(gvc t)
gen v_mln = v/1000000
twoway (line v_mln t if gvc == 0) (line v_mln t if gvc == 1,yaxis(2)), scheme(s2mono) legend(size(mediumsmall) rows(1) lab(1 "Importer only") lab(2 "Importer and exporter")) xsize(6) ysize(4) ytitle("Trade value in million CHF") ytitle("Trade value in million CHF", axis(2)) xtitle("Year") xlab(2016(1)2018,nogrid)
graph export "$SwissMRL/Results/Figures/Figure2b.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/Figure2b.png", as(png) replace
restore 

* ******************************************************************************
* (3a) Firm sizes defined based on number of employees in the firm (Table 5)    *
* ******************************************************************************
replace firm_size = "small" if firm_size == "< 10 persons"
replace firm_size = "medium" if firm_size == "10-49 persons"
replace firm_size = "large" if firm_size == "50-249 persons"
replace firm_size = "large" if firm_size == "> 249 persons"

egen fsize_id = group(firm_uid firm_size)
bys firm_uid t: egen new = nvals( fsize_id )
	
	tab firm_size, gen(size) 
	
	gen mrl_small  = mrl_od * size3
	gen mrl_medium = mrl_od * size2
	gen mrl_large  = mrl_od * size1
	
reghdfe ln_v  mrl_od mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
eststo fsize_employment

esttab main gvc fsize_employment  using "$SwissMRL/Results/Tables/Table4.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Main""GVC""Size") title("Pesticide regulations and firm-level imports: firm-origin-product level estimates") ar2(3)  b(3) se(3) replace nogap drop(_cons) order(mrl_od gvc mrl_gvc mrl_medium mrl_large  ln_mfn) compress

* (b) Firm sizes defined based on import volumes (Table A3)
bys firm_uid t : egen v_total = sum(v) 
xtile pct = v_total, nq(3)
tab pct, gen(import_share)

	gen mrl_size1  = mrl_od * import_share1
	gen mrl_size2  = mrl_od * import_share2
	gen mrl_size3  = mrl_od * import_share3
	
	reghdfe ln_v mrl_od mrl_size2 mrl_size3 ln_mfn, absorb(fcp ct ) cluster(fpt)
	eststo fsize_import

	esttab fsize_import using "$SwissMRL/Results/Tables/TableA3.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Size") title("Pesticide regulations and firm-level imports: firm-origin-product level estimates") ar2(3)  b(3) se(3) replace nogap drop(_cons) order(mrl_od mrl_size2 mrl_size3 ln_mfn) compress
	

	
** (c) Multi-product and multi-origin firms (Table 6)
gen hs4 = int(hs8/10000)
bys firm_uid t: egen multiprod = nvals(hs4)
gen multi_prod = 1 if multiprod > 1
replace  multi_prod = 0 if multiprod == 1
tab multi_prod, gen(multiprodfirm)
	gen mrl_multi  = mrl_od * multiprodfirm2
	gen mrl_single = mrl_od * multiprodfirm1
	
	reghdfe ln_v mrl_od mrl_multi ln_mfn , absorb(fcp ct) cluster(fpt)
	eststo multiprod
* count the number of mono-industry firms
bys firm_uid: egen multi_ind = nvals(hs4)
egen multi_ind_firm = nvals(firm_uid) if multi_ind > 1 // 3224 firms
egen mono_ind_firm = nvals(firm_uid) if multi_ind == 1 // 7047 firms
display (7047 / (3224 + 7047)) * 100 

bys firm_uid t: egen multidest = nvals(iso_o)
gen multi_dest = 1 if multidest > 1
replace  multi_dest = 0 if multidest == 1
tab multi_dest, gen(multidestfirm)
	gen mrl_multi_dest  = mrl_od * multidestfirm2
	gen mrl_single_dest = mrl_od * multidestfirm1
	
	reghdfe ln_v  mrl_od mrl_multi_dest ln_mfn , absorb(fcp ct) cluster(fpt)
	eststo multicountry
	
	esttab multiprod multicountry using "$SwissMRL/Results/Tables/Table8.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	title("Pesticide regulations and firm-level imports: firm-origin-product level estimates") ar2(3)  b(3) se(3) replace nogap drop(_cons) order(mrl_od mrl_multi mrl_multi_dest ln_mfn) compress
	
* count the number of mono-origin firms
bys firm_uid: egen multi_origin = nvals(iso_o)
egen multi_origin_firm = nvals(firm_uid) if multi_origin > 1 // 2626 firms
egen mono_origin_firm = nvals(firm_uid) if multi_origin == 1 // 7645 firms
display (7645 / (2656 + 7645)) * 100 // 74%


	
ppmlhdfe v  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
eststo main_ppml 
ppmlhdfe v  mrl_od gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
eststo gvc_ppml 
ppmlhdfe v  mrl_od mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
eststo fsize_employment_ppml
	
esttab main_ppml gvc_ppml fsize_employment_ppml  using "$SwissMRL/Results/Tables/TableA4.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Main""GVC""Size") title("Pesticide regulations and firm-level imports: differences across firm sizes") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

	
* Appendix 
* Control for EU membership 
gen int eu = 0 
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
replace eu = 1 if iso_o == "`x'"
}

	tab eu, gen(euu) 
	gen mrl_noeu = mrl_od * euu1
	gen mrl_eu   = mrl_od * euu2
	
	reghdfe ln_v  mrl_od mrl_eu eu ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo main
	reghdfe ln_v  mrl_od mrl_eu eu gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo gvc
	reghdfe ln_v  mrl_od mrl_eu eu mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
	eststo fsize_employment

esttab main gvc fsize_employment using "$SwissMRL/Results/Tables/TableA8.tex", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Main""GVC""Size") title("Heterogeneity across EU and non-EU origins") order(mrl_od mrl_eu gvc mrl_gvc mrl_medium mrl_large  ln_mfn) ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
** Endogeneity (Does the effect vary depending on how important the product is in import basket)
bys  hs8 t: egen import_total = sum(v)
_pctile import_total , percentiles(50)
scalar Median = r(r1) 
display Median 
	
	reghdfe  ln_v mrl_od ln_mfn if import_total <= Median, absorb(fcp ct) cluster(fpt)
	eststo main1
	reghdfe ln_v  mrl_od gvc mrl_gvc ln_mfn if import_total <= Median, absorb(fcp ct) cluster(fpt)
	eststo gvc1
	reghdfe ln_v  mrl_od mrl_medium mrl_large  ln_mfn if new == 1 & import_total <= Median, absorb(fcp ct) cluster(fpt)
	eststo fsize_employment1
	
	reghdfe  ln_v mrl_od ln_mfn if import_total > Median, absorb(fcp ct) cluster(fpt)
	eststo main2
	reghdfe ln_v  mrl_od gvc mrl_gvc ln_mfn if import_total > Median, absorb(fcp ct) cluster(fpt)
	eststo gvc2
	reghdfe ln_v  mrl_od mrl_medium mrl_large  ln_mfn if new == 1 & import_total > Median, absorb(fcp ct) cluster(fpt)
	eststo fsize_employment2

esttab  main2 gvc2 fsize_employment2 main1 gvc1 fsize_employment1  using "$SwissMRL/Results/Tables/TableA9.tex", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Main""GVC""Size""Main""GVC""Size") title("Import percentiles") order(mrl_od gvc mrl_gvc mrl_medium mrl_large  ln_mfn) ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

* Keeping Sample as in column (3) 
reghdfe ln_v  mrl_od ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
eststo main
reghdfe ln_v  mrl_od gvc mrl_gvc ln_mfn  if new == 1, absorb(fcp ct) cluster(fpt)
eststo gvc 



* ******************************************************************************
* (1) Decompose the effect into different margins 
* ******************************************************************************
use "$SwissMRL/Data/mrl_data_v6", clear 

	egen id = group( firm_uid iso_o hs8)
	duplicates tag id t, gen(isdup)
	drop if isdup > 0
	drop isdup
	xtset id t

	gen hs6 = int(hs8/100)
	rename v total_imports
	rename q total_qty 
	*bys firm_uid iso_o hs6 t: egen double n_firms  	= nvals(firm_uid ) 		// Number of importing firms
	bys firm_uid iso_o hs6 t: egen double n_products  	= nvals(hs8) 			// Number of imported products
	bys firm_uid iso_o hs6 t: egen double v 			= sum(total_imports) 	// Total import value
	bys firm_uid iso_o hs6 t: egen double q 			= sum(total_qty) 	// Total import value
	gen double v_mean = (v / n_products ) 	// Import value per product per firm
	gen double uv = v_mean/q
	bys iso_o hs6 t: egen mfn_tariff 	= mean(mfn)
	bys iso_o hs6 t: egen mrl_od2 	= mean(mrl_od)
	keep firm_size firm_uid iso_o hs6 v* q n_* mfn_tariff t uv mrl_od2 export
	bys firm_uid iso_o hs6 t: gen dup = _n
	keep if dup == 1
	rename mrl_od2 mrl_od
	
	gen double ln_products = log( n_products)
	gen double ln_v_mean = log(v_mean)
	gen double ln_v = log(v)
	gen double ln_q = log(q)
	gen double ln_uv = log(uv)
	gen double ln_mfn = log(1+mfn_tariff)
	
	egen fpt = group(firm_uid hs6 t)
	egen fcp = group(firm_uid iso_o hs6)
	egen ct = group(iso_o t)
	egen ft = group(firm_uid t)
	

* Summary statistics	
*reghdfe  ln_v mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
*gen sample = 1 if e(sample) == 1
*sutex v q uv n_firms v_mean mrl_od mfn if sample == 1, minmax dig(3) // Table 3 


foreach v of varlist ln_v ln_products ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'_main
}

* (2) The role of Global Value Chains 										   *    
gen gvc = 1 if export != .
replace gvc = 0 if gvc == .
tab gvc, gen(gvc_) 
gen mrl_nogvc = mrl_od * gvc_1
gen mrl_gvc= mrl_od * gvc_2 

foreach v of varlist ln_v ln_products ln_v_mean{
	reghdfe `v'  mrl_od gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'_gvc
}

* (3) Heterogeneity  across firm sizes  									   *
* (a) Firm sizes defined based on number of employees in the firm (Table 5)
replace firm_size = "small" if firm_size == "< 10 persons"
replace firm_size = "medium" if firm_size == "10-49 persons"
replace firm_size = "large" if firm_size == "50-249 persons"
replace firm_size = "large" if firm_size == "> 249 persons"

egen fsize_id = group(firm_uid firm_size)
bys firm_uid t: egen new = nvals( fsize_id )
	
	tab firm_size, gen(size) 
	
	gen mrl_small  = mrl_od * size3
	gen mrl_medium = mrl_od * size2
	gen mrl_large  = mrl_od * size1
	
foreach v of varlist ln_v ln_products ln_v_mean{
	reghdfe `v'  mrl_od mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
	eststo `v'_size
}
drop new fsize_id

esttab ln_v_main ln_products_main ln_v_mean_main ln_v_gvc ln_products_gvc ln_v_mean_gvc ln_v_size ln_products_size ln_v_mean_size using "$SwissMRL/Results/Tables/Table5.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin""Total imports""Extensive margin""Intensive margin""Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: import margins") order(mrl_od gvc mrl_gvc mrl_medium mrl_large  ln_mfn) ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	

* Graph of margins against total imports
reghdfe  ln_v, absorb(ft ct) resid(v_resid)
reghdfe  ln_v_mean, absorb(ft ct) resid(mean_resid)
reghdfe  ln_products, absorb(ft ct) resid(prod_resid)

binscatter mean_resid v_resid, scheme(s2mono) xsize(6) ysize(4)  xtitle("Log (total imports)") ytitle("Log (average imports per firm)")
graph export "$SwissMRL/Results/Figures/FigureA1.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureA1.png", as(png) replace

binscatter prod_resid v_resid, scheme(s2mono) xsize(6) ysize(4)  xtitle("Log (total imports)") ytitle("Log (number of products imported)") 
graph export "$SwissMRL/Results/Figures/FigureA2.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureA2.png", as(png) replace

*

/*
use "$SwissMRL/Data/mrl_data_v6", clear 

egen id = group( firm_uid iso_o hs8)
duplicates tag id t, gen(isdup)
drop if isdup > 0
drop isdup
xtset id t
	
	gen hs6 = int(hs8/100)
	rename v total_imports
	rename q total_qty 
	*bys firm_uid iso_o hs6 t: egen double n_firms  	= nvals(firm_uid ) 		// Number of importing firms
	bys firm_uid iso_o hs6 t: egen double n_products  	= nvals(hs8) 			// Number of imported products
	bys firm_uid iso_o hs6 t: egen double v 			= sum(total_imports) 	// Total import value
	bys firm_uid iso_o hs6 t: egen double q 			= sum(total_qty) 	// Total import value
	gen double v_mean = (v / n_products ) 	// Import value per product per firm
	gen double uv = v_mean/q
	bys iso_o hs6 t: egen mfn_tariff 	= mean(mfn)
	bys iso_o hs6 t: egen mrl_od2 	= mean(mrl_od)
	keep firm_size firm_uid iso_o hs6 v* q n_* mfn_tariff t uv mrl_od2 export
	bys firm_uid iso_o hs6 t: gen dup = _n
	keep if dup == 1
	rename mrl_od2 mrl_od
	
	gen double ln_products = log( n_products)
	gen double ln_v_mean = log(v_mean)
	gen double ln_v = log(v)
	gen double ln_q = log(q)
	gen double ln_uv = log(uv)
	gen double ln_mfn = log(1+mfn_tariff)
	
	egen fpt = group(firm_uid hs6 t)
egen fcp = group(firm_uid iso_o hs6)
egen ct = group(iso_o t)
	
	
foreach v of varlist  ln_v ln_products ln_v_mean {
	reghdfe `v' mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'
}


foreach v of varlist  ln_v ln_products ln_v_mean {
	reghdfe `v' mrl_od mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
	eststo `v'
}

foreach v of varlist  ln_v ln_products ln_v_mean {
	reghdfe `v' mrl_od gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'
}


reghdfe ln_v  mrl_od gvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)

	
	
	
	
	
	
	
	gen double ln_q = log(q)
	
	
* Generating fixed effects
	
	egen ft  = group(firm_uid t)
	
	egen pt = group(hs8 t)
	egen fct = group(firm_uid iso_o t)
	
	egen cpt = group(iso_o hs8 t)
	gen uv = v/q
	gen ln_uv = log(v/q)

	bys hs8 t: egen double n_firms  = nvals(firm_uid ) 		// Number of importing firms
	gen double v_mean = (v / n_firms) 	// Import value per product per firm
	gen double ln_firms = log(n_firms)
	gen double ln_v_mean = log(v_mean)	

* Summary statistics	
reghdfe  ln_v mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
gen sample = 1 if e(sample) == 1
sutex v q uv n_firms v_mean mrl_od mfn if sample == 1, minmax dig(3) // Table 3 

* ***********************************************************************************
* (1) Decompose the effect into different margins 
* ***********************************************************************************
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'
}

esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table4.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table4.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
* ******************************************************************************
* (2) The role of Global Value Chains 										   *    
* ******************************************************************************
gen gvc = 1 if export != .
replace gvc = 0 if gvc == .
tab gvc, gen(gvc_) 
gen mrl_nogvc = mrl_od * gvc_1
gen mrl_gvc= mrl_od * gvc_2 

foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_nogvc mrl_gvc ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'
}

esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table5.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("The role of Global Value Chain participation") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table5.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("The role of Global Value Chain participation") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
twoway (kdensity ln_v if  gvc == 0, lp(solid)) (kdensity ln_v if  gvc == 1), scheme(s2mono) legend(size(mediumsmall) rows(1) lab(1 "Importer only") lab(2 "Importer and exporter")) ytitle("kdensity") xtitle("Trade value in CHF (logs)") xsize(6) ysize(4)
graph export "$SwissMRL/Results/Figures/Figure2a.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/Figure2a.png", as(png) replace

preserve 
collapse(sum) v q, by(gvc t)
gen v_mln = v/1000000
twoway (line v_mln t if gvc == 0) (line v_mln t if gvc == 1,yaxis(2)), scheme(s2mono) legend(size(mediumsmall) rows(1) lab(1 "Importer only") lab(2 "Importer and exporter")) xsize(6) ysize(4) ytitle("Trade value in million CHF") ytitle("Trade value in million CHF", axis(2)) xtitle("Year") xlab(2016(1)2018,nogrid)
graph export "$SwissMRL/Results/Figures/Figure2b.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/Figure2b.png", as(png) replace
restore 

* ******************************************************************************
* (3) Heterogeneity  across firm sizes  									   *
* ******************************************************************************
* (a) Firm sizes defined based on number of employees in the firm (Table 5)
replace firm_size = "small" if firm_size == "< 10 persons"
replace firm_size = "medium" if firm_size == "10-49 persons"
replace firm_size = "large" if firm_size == "50-249 persons"
replace firm_size = "large" if firm_size == "> 249 persons"

egen fsize_id = group(firm_uid firm_size)
bys firm_uid t: egen new = nvals( fsize_id )
	
	tab firm_size, gen(size) 
	
	gen mrl_small  = mrl_od * size3
	gen mrl_medium = mrl_od * size2
	gen mrl_large  = mrl_od * size1
	
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_small mrl_medium mrl_large  ln_mfn if new == 1, absorb(fcp ct) cluster(fpt)
	eststo `v'
}
drop new fsize_id
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table6.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: differences across firm sizes") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Table6.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: differences across firm sizes") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
	coefplot ln_v ln_firms ln_v_mean, ///
	drop(_cons ln_mfn) xline(0, lcolor(red)) scheme(gg_hue) xlabel("") ///
	recast(bar) barw(0.22) vertical ylab(-1.4(.2)0.1) levels(90) ciopts(recast(rcap) color(gs8)) citop format(%9.3f) ///
	addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(12) mlabsize(vsmall) mlabcolor(black)) ///
	legend(order(1 "Total imports" 3 "Number of products" 5 "Average imports per product")) ///
	legend(col(1) ring(0) pos(5)) xsize(6) ysize(4) plotregion(fcolor(white) color(black)) 
	
	
** (b) Firm sizes defined based on import volumes (Table A3)
bys firm_uid t : egen v_total = sum(v) 
xtile pct = v_total, nq(3)
tab pct, gen(import_share)

	gen mrl_size1  = mrl_od * import_share1
	gen mrl_size2  = mrl_od * import_share2
	gen mrl_size3  = mrl_od * import_share3
	
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v' mrl_od mrl_size2 mrl_size3 ln_mfn, absorb(fcp ct ) cluster(fpt)
	eststo `v'
}
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableA4.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: differences across firm sizes") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableA4.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: differences across firm sizes") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
** (c) Multi-product and multi-origin firms (Table 6)
gen hs4 = int(hs8/10000)
bys firm_uid t: egen multiprod = nvals(hs4)
gen multi_prod = 1 if multiprod > 1
replace  multi_prod = 0 if multiprod == 1
tab multi_prod, gen(multiprodfirm)
	gen mrl_multi  = mrl_od * multiprodfirm2
	gen mrl_single = mrl_od * multiprodfirm1

foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od mrl_multi ln_mfn , absorb(fcp ct) cluster(fpt)
	eststo `v'
}

bys firm_uid t: egen multidest = nvals(iso_o)
gen multi_dest = 1 if multidest > 1
replace  multi_dest = 0 if multidest == 1
tab multi_dest, gen(multidestfirm)
	gen mrl_multi_dest  = mrl_od * multidestfirm2
	gen mrl_single_dest = mrl_od * multidestfirm1
	
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od mrl_multi_dest ln_mfn , absorb(fcp ct) cluster(fpt)
	eststo `v'_d
}

esttab ln_v ln_v_d ln_firms ln_firms_d ln_v_mean ln_v_mean_d using "$SwissMRL/Results/Tables/Table7.tex", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: multi-industry and multi-origin firms") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab ln_v ln_v_d ln_firms ln_firms_d ln_v_mean ln_v_mean_d using "$SwissMRL/Results/Tables/Table7.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: multi-industry and multi-origin firms") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress


* ***********************************************************************************
* (4) Extensions											    *
* ***********************************************************************************
** Assessing quantity and price effects

reghdfe ln_q  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
eststo result_q
gen sample2 = 1 if e(sample) == 1
/*Trim extreme changes in unit values from one year to the other 
	sort id t 					
	gen dluv = ln_uv - l.ln_uv	
	_pctile dluv, p(1 91)
	drop if (dluv<r(r1) | dluv>r(r2)) & dluv!=.
	drop dluv
* Trim extreme values in the 1st and 99th percentile
	sum uv, d 		
	_pctile uv, p(1 99)
	drop if (uv<r(r1) | uv>r(r2)) 
	*/
egen fp = group(firm_uid hs8)
reghdfe ln_uv mrl_od ln_mfn if sample2 == 1, absorb(fp ct) cluster(fpt)
eststo result_uv


esttab result_q result_uv using "$SwissMRL/Results/Tables/Table8.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab result_q result_uv using "$SwissMRL/Results/Tables/Table8.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	

* Heterogeneous effects for product differentiation
preserve

gen hs3 = int(hs8/100000)
gen hs6 = int(hs8/100)
merge m:1 iso_d hs3 using "$SwissMRL/Data/Elasticity of subsitution HS 3-digit", keep(1 3) nogen

sort id t 					
gen dluv = ln_uv - l.ln_uv	
_pctile dluv, p(1 99)
drop if (dluv<r(r1) | dluv>r(r2)) & dluv!=.
drop dluv
* Trim extreme values in the 1st and 99th percentile
sum uv, d 		
_pctile uv, p(1 99)
drop if (uv<r(r1) | uv>r(r2)) 

* Estimating quality based on Khandelwal, Schott and Wei (2013) 
gen depvar = ln_q + (elsubs*ln_uv)
encode firm_uid, gen(importer)
bys firm_uid hs4 t: gen number_exp2 =_N //drop if number_exp<2
egen importer_hs6 = group(firm_uid hs4)
egen code=group(importer_hs6) if elsubs!=. & number_exp2>1
egen importer_year = group(firm_uid t)
gen qual=.
su code

forv i=1/6259{
    set more off
    tabulate hs8 if code==`i', gen(dp)
	reghdfe depvar dp* if code==`i', absorb(importer_year) resid
    predict resid`i', r
	replace qual=resid`i'/(elsubs-1) if code==`i'
    drop dp*
    clear matrix
}
drop  resid*

*
binscatter qual ln_uv, scheme(s1mono) xtitle("Log of unit values")  ///
				  ytitle("Estimated product quality")  xsize(6) ysize(4) ms(o) mc(black) lc(black)
	graph export "$SwissMRL/Results/Figures/FigureQual.png", as(png) replace	 
	
	bysort firm_uid hs8 iso_o (t): gen qual_change = qual-qual[_n-1]
	bysort firm_uid hs8 iso_o (t): gen uv_change = ln_uv - ln_uv[_n-1]
	
binscatter qual_change uv_change , scheme(s1mono) xtitle("Change in log of unit values") ///
				  ytitle("Change in estimated product quality")  xsize(6) ysize(4) ms(o) mc(black) lc(black)
	graph export "$SwissMRL/Results/Figures/FigureQual2.png", as(png) replace	
* 
gen mrl_qual = mrl_od * qual
reghdfe ln_v  mrl_od qual  mrl_qual ln_mfn, absorb(fcp ct ) cluster(fpt)
eststo qual 
reghdfe ln_uv mrl_od qual  mrl_qual ln_mfn, absorb(fcp ct ) cluster(fpt)
eststo qual_uv 

esttab qual qual_uv using "$SwissMRL/Results/Tables/TableA6.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab qual qual_uv using "$SwissMRL/Results/Tables/TableA6.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

*Quality ladder
bys hs8: egen maxladder = max(qual)
bys hs8: egen minladder = min(qual)
gen ladder = maxladder - minladder
_pctile ladder, percentiles(50) 
gen pLadder = r(r1)

reghdfe ln_v  mrl_od ln_mfn if ladder >  pLadder, absorb(fcp ct) cluster(fpt)
eststo v_hq
reghdfe ln_v  mrl_od ln_mfn if ladder <= pLadder, absorb(fcp ct) cluster(fpt)
eststo v_lq

reghdfe ln_uv mrl_od ln_mfn if ladder >  pLadder, absorb(fp ct) cluster(fpt)
eststo uv_hq
reghdfe ln_uv mrl_od ln_mfn if ladder <= pLadder, absorb(fp ct) cluster(fpt)
eststo uv_lq

foreach v of varlist ln_v ln_uv{
	reghdfe `v'  mrl_od ln_mfn if ladder > pLadder, absorb(fcp ct) cluster(fpt)
	eststo `v'_hq
}

foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn if ladder <= pLadder, absorb(fcp ct) cluster(fpt)
	eststo `v'_lq
}

esttab v_hq uv_hq v_lq uv_lq using "$SwissMRL/Results/Tables/Table9.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab v_hq uv_hq v_lq uv_lq using "$SwissMRL/Results/Tables/Table9.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
restore

** (2) Simulatating a one s.d. increase in MRL_opd
preserve
reghdfe  ln_v mrl_od ln_mfn, absorb(fcp ct, save) cluster(fpt)
reg ln_v mrl_od ln_mfn __hdfe1__ __hdfe2__, cluster(fpt)
predict v_hat, xb 

twoway (scatter ln_v v_hat )  (lfit ln_v v_hat), leg(off) scheme(s2mono) xsize(6) ysize(4)  xtitle("Predicted import values (log)") ytitle("Observed import values (log)")
graph export "$SwissMRL/Results/Figures/FigurePredictTrade.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigurePredictTrade.png", as(png) replace

gen v_hat_calc = _b[mrl_od]*mrl_od + _b[ln_mfn]*ln_mfn + __hdfe1__ + __hdfe2__ + _b[_cons]
gen mrlod_new = mrl_od + 0.267 // change this to minus to simulate a one s.d. decrease in MRL_opd

/* Run this to simulate case of EU and Swiss standards harmonised
gen eu = .  
drop mrlod_new
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
	replace eu = 1 if iso_o == "`x'"
}
replace eu = 0 if eu == .
gen mrlod_new = mrl_od
replace mrlod_new = 1 if eu == 1 */

gen v_sim = _b[mrl_od]*mrlod_new + _b[ln_mfn]*ln_mfn + __hdfe1__ + __hdfe2__ + _b[_cons]

twoway (kdensity v_hat) (kdensity v_sim,lp(dash)) // comapre simulated and predicted trade flows

gen predicted_trade = exp(v_hat)
gen sim_trade_mrlnew = exp(v_sim)

egen sim_new = sum(sim_trade_mrlnew/1000000)
egen predict = sum(predicted_trade/1000000)

gen diff = sim_new - predict
gen perc_change = (diff / predict) * 100
keep predict diff sim_new perc_change
duplicates drop 

order predict sim_new diff

foreach v of varlist predict sim_new diff{
	replace `v' = `v'/1000000
}

restore

** (3) Calculating ad valorem equivalent of MRL_od
reghdfe  ln_v mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
sum mrl_od
scalar sd_mrl = r(sd)
scalar TariffEquivalentMRL = (exp(_b[mrl_od]*1/(_b[ln_mfn])) - 1) * 100
display TariffEquivalentMRL
scalar TariffEquivalentMRL = (exp(_b[mrl_od]*sd_mrl/(_b[ln_mfn])) - 1) * 100
display TariffEquivalentMRL

* ***********************************************************************************
* (5) Sensitivity analysis											    *
* ***********************************************************************************
* Using the PPML estimator
ppmlhdfe v 	  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
eststo three
ppmlhdfe q 	  mrl_od ln_mfn, absorb(fcp ct) cluster(fpt)
eststo four

esttab three four using "$SwissMRL/Results/Tables/TableA7.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab three four using "$SwissMRL/Results/Tables/TableA7.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
* Control for EU membership 
gen int eu = 0 
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
replace eu = 1 if iso_o == "`x'"
}

	tab eu, gen(euu) 
	gen mrl_noeu = mrl_od * euu1
	gen mrl_eu   = mrl_od * euu2
	
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od mrl_eu eu ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'
}

esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableA8.tex", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Heterogeneity across EU and non-EU origins") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableA8.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Heterogeneity across EU and non-EU origins") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

** Endogeneity (Does the effect vary depending on how important the product is in import basket)
/*bys  hs8 t: egen import_total = sum(v)
xtile pct = import_total, nq(2)

tab pct, gen(pct_d) 
	
	gen mrl_lowimport2  = mrl_od * pct_d1
	gen mrl_highimport2 = mrl_od * pct_d2

foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v' mrl_od mrl_highimport2  ln_mfn, absorb(fcp ct) cluster(fpt)
	eststo `v'_1
}
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn if pct == 2, absorb(fcp ct) cluster(fpt)
	eststo `v'
}

esttab ln_v_1 ln_firms_1 ln_v_mean_1 ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Endogeneity.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

esttab ln_v_1 ln_firms_1 ln_v_mean_1 ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/Endogeneity.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("""""") title("Baseline") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
***/ 

bys hs8 t: egen import_share = sum(v)
sum import_share, d
gen import_share_dummy = 1 if import_share > 1.11e+07
replace import_share_dummy = 0 if import_share <= 1.11e+07

*tab import_share_dummy, gen(import_share_d) 
*gen mrl_lowimport  = mrl_od * import_share_d1
*gen mrl_highimport = mrl_od * import_share_d2
	
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn if import_share <= 1.11e+07, absorb(fcp ct) cluster(fpt)
	eststo `v'
}
foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_od ln_mfn if import_share > 1.11e+07, absorb(fcp ct) cluster(fpt)
	eststo `v'_d
}

esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableA9.tex", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: share of imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
esttab ln_v ln_v_d ln_firms ln_firms_d ln_v_mean ln_v_mean_d using "$SwissMRL/Results/Tables/TableA9.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 	 	
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports: share of imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
	
* Include traditional gravity variables
gen ln_distance = log(distcap)
gen ln_gdp = log(gdp)

foreach v of varlist ln_v ln_q{
reghdfe `v'  mrl_od ln_mfn ln_distance ln_gdp contig comlang_off rta, absorb(fpt)
eststo `v'
}

foreach v of varlist v q{
ppmlhdfe `v'  mrl_od ln_mfn ln_distance ln_gdp contig comlang_off rta, absorb(fpt)
eststo `v'_p
}

esttab ln_v v_p ln_q q_p using "$SwissMRL/Results/Tables/TableA5.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab ln_v v_p ln_q q_p using "$SwissMRL/Results/Tables/TableA5.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress

	
** Measure standards relative to the Codex

use "$SwissMRL/Data/mrl_data_codex", clear 
egen id = group( firm_uid iso_o hs8)
duplicates tag id t, gen(isdup)
drop if isdup > 0
drop isdup
xtset id t

gen double ln_v = log(v)
	gen double ln_q = log(q)
	gen double ln_mfn = log(1+mfn)
	
* Generating fixed effects
	egen fpt = group(firm_uid hs8 t)
	egen fc  = group(firm_uid iso_o)
	egen ct = group(iso_o t)

	bys hs8 t: egen double n_firms  = nvals(firm_uid ) 		// Number of importing firms
	gen double v_mean = (v / n_firms) 	// Import value per product per firm
	gen double ln_firms = log(n_firms)
	gen double ln_v_mean = log(v_mean)	

	foreach v of varlist ln_v ln_firms ln_v_mean{
	reghdfe `v'  mrl_cod ln_mfn, absorb(fc ct) cluster(fpt)
	eststo `v'
}


esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableCodex.tex", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress
esttab ln_v ln_firms ln_v_mean using "$SwissMRL/Results/Tables/TableCodex.rtf", star(* 0.10 ** 0.05 *** 0.01) /// 		
	mtitles("Total imports""Extensive margin""Intensive margin") title("Pesticide regulations and firm-level imports") ar2(3)  b(3) se(3) replace nogap drop(_cons) compress	

* DESCRIPTIVES
preserve
use "$SwissMRL/Data/mrl_data_v5", clear
	rename country iso_o
	keep if t == 2016
	collapse mrl_od, by(iso_o)
	gen mrl = string( mrl_od ,"%4.2f")
	destring mrl, replace
	rename iso_o iso_a3
	save  "$SwissMRL/Data/map", replace
	
	use "$SwissFirms/Data/worlddata.dta", clear
	merge m:1 iso_a3 using   "$SwissMRL/Data/map", keep(1 3) nogen
	spmap mrl using "$SwissFirms/Data/worldcoor.dta" if admin!="Antarctica", id(id) clm(custom) clbreaks(0.8(0.2)1.6)  fcolor(Greens2) ///
			legend(pos(7) title("new") size(2.5)) legstyle(2)  xsize(6) ysize(4)
	graph export "$SwissMRL/Results/Figures/map_differences.eps", as(eps) replace
	graph export "$SwissMRL/Results/Figures/map_differences.png", as(eps) replace
restore

* Sumary statistics
preserve

replace firm_size = "small"  if firm_size == "< 10 persons"
replace firm_size = "medium" if firm_size == "10-49 persons"
replace firm_size = "large"  if firm_size == "50-249 persons"
replace firm_size = "large"  if firm_size == "> 249 persons"

egen fsize_id = group(firm_uid firm_size)
bys firm_uid t: egen no_dup = nvals( fsize_id )
keep if no_dup == 1

	bysort firm_size: egen mean_v = mean(v) // *mean exports per firm
	bysort firm_size: egen mean_q = mean(q) // *mean exports per firm
	*bysort firm_size: egen mean_uv = mean(uv) // *median exports per firm
	bysort firm_size: egen uid_unique = nvals(firm_uid) // *total number of firms
	bysort firm_size: egen hs8_unique = nvals(hs8) // *total number of products
	bysort firm_size: egen isod_unique = nvals(iso_o) // *total number of destinations
	bysort firm_size: gen N = _N 
	
	drop fp
	egen fp =group(firm_uid hs8 )  // products per firm
	bys firm_size: egen new = nvals(fp) 
	bys firm_size: gen hs8_firm = new / hs8_unique 
	
	egen dp =group(firm_uid iso_o) //destinations per firm
	bys firm_size: egen new2 = nvals(dp) 
	bys firm_size: gen isod_firm = new2 / uid_unique 
	
	gen mean_v2 = string( mean_v ,"%4.2f")
	gen mean_q2 = string( mean_q ,"%4.2f")
	gen isod_firm2 = string( isod_firm ,"%4.2f")
	gen hs8_firm2 = string( hs8_firm ,"%4.2f")
	*gen uv2 = string( mean_uv ,"%4.2f")

	keep  firm_size N uid_unique hs8_unique isod_unique mean_v2 mean_q2 isod_firm2
	order firm_size N uid_unique hs8_unique isod_unique mean_v2 mean_q2 isod_firm2
	duplicates drop 

	texsave * using "$SwissMRL/Results/Tables/Table2.tex", decimalalign  replace
restore

preserve
	bysort gvc: egen mean_v = mean(v) // *mean exports per firm
	bysort gvc: egen mean_q = mean(q) // *mean exports per firm
	bysort gvc: egen uid_unique = nvals(firm_uid) // *total number of firms
	bysort gvc: egen hs8_unique = nvals(hs8) // *total number of products
	bysort gvc: egen isod_unique = nvals(iso_o) // *total number of destinations
	bysort gvc: gen N = _N 
	drop fp
	egen fp =group(firm_uid hs8 )  // products per firm
	bys gvc: egen new = nvals(fp) 
	bys gvc: gen hs8_firm = new / hs8_unique 
	
	egen dp =group(firm_uid iso_o) //destinations per firm
	bys gvc: egen new2 = nvals(dp) 
	bys gvc: gen isod_firm = new2 / uid_unique 
	
	gen mean_v2 = string( mean_v ,"%4.2f")
	gen mean_q2 = string( mean_q ,"%4.2f")
	gen isod_firm2 = string( isod_firm ,"%4.2f")
	gen hs8_firm2 = string( hs8_firm ,"%4.2f")
	*gen uv2 = string( mean_uv ,"%4.2f")

	keep  gvc N uid_unique hs8_unique isod_unique mean_v2 mean_q2 isod_firm2
	order gvc N uid_unique hs8_unique isod_unique mean_v2 mean_q2 isod_firm2
	duplicates drop 

	texsave * using "$SwissMRL/Results/Tables/TableA3.tex", decimalalign  replace
restore 
	
** Graph appendix
reghdfe  ln_v, absorb(ft ct) resid(v_resid)
reghdfe  ln_v_mean, absorb(ft ct) resid(mean_resid)
reghdfe  ln_firms, absorb(ft ct) resid(firm_resid)

binscatter mean_resid v_resid, scheme(s2mono) xsize(6) ysize(4)  xtitle("Log (total imports)") ytitle("Log (average imports per firm)")
graph export "$SwissMRL/Results/Figures/FigureA1.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureA1.png", as(png) replace

binscatter firm_resid v_resid, scheme(s2mono) xsize(6) ysize(4)  xtitle("Log (total imports)") ytitle("Log (number of importing firms)") 
graph export "$SwissMRL/Results/Figures/FigureA2.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureA2.png", as(png) replace

* Market attractiveness (meaured as gdp and gdp/distance) - Fontagne & Orefice (2018, EER) 
preserve
keep if t == 2018
bys firm_uid hs8 iso_o:  gen nvals = _n == 1
bys iso_o: replace nvals = sum(nvals)

bys iso_o : replace nvals = nvals[_N]
keep iso_o nvals gdp distw iso_o
duplicates drop
sort nvals
drop if nvals == 0 
	
* Market attractiveness (meaured as gdp and gdp/distance) - Fontagne & Orefice (2018, EER) 
	gen ln_gdp 		= log(gdp)
	gen ln_gdp_dist = log(gdp/distw)
	gen ln_dist 	= log(distw)
	gen ln_nvals 	= log(1 + nvals)

	graph twoway (scatter ln_nvals ln_gdp_dist, mlabel(iso_o) mlabposition(2) m(Oh)  msize(vsmall) mlabsize(vsmall)) ///
				 (lfit ln_nvals ln_gdp_dist), scheme(s2mono) leg(off) xtitle("GDP of origin country/distance (log)") ///
				  ytitle("Importing firm-HS8 combinations (log)") ///
				  xlabel(14 (2) 23, nogrid) ylabel(0(1)9, nogrid) xsize(6) ysize(4)
	graph export "$SwissMRL/Results/Figures/export_gdpdist.eps", as(eps) replace
	graph export "$SwissMRL/Results/Figures/export_gdpdist.png", as(png) replace
restore 

* variations in MRL over time 
preserve 
bys t: egen new = mean(mrl_od)
bys iso_o t: egen cnew = mean(mrl_od)
gen int eu = 0 
foreach x in BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
replace eu = 1 if iso_o == "`x'"
}

drop if eu == 1
drop if iso_o == "BHR"
drop if iso_o == "OMAN"
replace iso_o = "EU" if iso_o == "AUT"
twoway (line cnew t , by(iso_o, note(""))), scheme(s2mono) xsize(6) ysize(4) ytitle("Bilateral variation in MRLs by origin country") xlab(2016(1)2018,nogrid) 
graph export "$SwissMRL/Results/Figures/FigureMRLvariation.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureMRLvariation.png", as(png) replace

twoway (line new t,mlabel(new)), scheme(s2mono) xsize(6) ysize(4) ytitle("Bilateral variation in MRLs") xtitle("Year") xlab(2016(1)2018,nogrid) 
graph export "$SwissMRL/Results/Figures/FigureMRLvariationTime.eps", as(eps) replace
graph export "$SwissMRL/Results/Figures/FigureMRLvariationTime.png", as(png) replace

restore



* Maps
/*cd "$SwissMRL/Data/swisscantonsmod-master"
spshape2dta "$SwissMRL/Data/swisscantonsmod-master/ch-cantons.shp", replace
	merge m:1 NAME_1 using   "$SwissMRL/Data/votes", keep(3) nogen
	spmap yes_1 using ch-cantons_shp, id(ID_1) fcolor(Reds2) clm(custom) clbreaks(20(1)60)  legend(off) label(x(_X) y(_Y) label(yes_1) size(small) color(white)) xsize(6) ysize(4)
	graph export "$SwissMRL/Results/Figures/map_votes.png", as(png) replace*/