* MAXIMUM RESIDUE LIMIT DATA
forvalues v = 2016(1)2018{
	import delimited "$SwissMRL\Data\mrlbase`v'.csv", varnames(1) clear
	gen t = `v'
	save "$SwissMRL/Data/MRL`v'", replace 
}
	append using "$SwissMRL/Data/MRL2017"
	append using "$SwissMRL/Data/MRL2016"
	drop if crop == ""
	drop if country == "EUROPEAN-UNION-CONTAMINANTS"
	compress
	duplicates drop

	replace activ = "Z-9-DODECENYL-ACETATE" if activ == "Z.9-DODECENYL-ACETATE" 
* Check  activ ingredients for duplicates and multiple names for same ingredients
	save "$SwissMRL/Data/mrl_data", replace
*
preserve
	bys country: egen n_crops = nvals(crop)
	bys country: egen n_active = nvals(activ)
	keep n_crops n_active country 
	duplicates drop 
	
	replace country = "EU" if country == "EU-MRLS-HARMONIZED"
	replace country = "GULF CC" if country == "GULF-COOPERATION-COUNCIL"
	replace country = "ASEAN" if country == "ASEAN COUNTRIES"
			 
	label var n_crops	"Number of regulated products"
	label var n_active	"Number of regulated active ingredients"
			 
	multidot n_crops n_active, over(country) by(row(1) compact) recast(hbar) subtitle(, size(small)) ytitle("") ///
		xla(#5, labsize(small)) scheme(plotplainblind) bfcolor(gray)  xsize(6) ysize(4)
	graph export "$SwissMRL/Results/Figures/FigureA1.eps", as(eps) replace
	graph export "$SwissMRL/Results/Figures/FigureA1.png", as(png) replace
restore
*

* Keep only active ingredients regulated in Switzerland
preserve
	keep if country == "SWITZERLAND"
	rename mrl mrl_swiss
	drop country
	save "$SwissMRL/Data/mrl_data_swiss", replace
restore

* Keep only Codex standards
preserve
	keep if country == "CODEX"
	rename mrl mrl_codex
	drop country
	save "$SwissMRL/Data/mrl_data_codex", replace
restore

* merge it with all other country mrls
use "$SwissMRL/Data/mrl_data", clear 
	drop if country == "SWITZERLAND" | country == "CODEX"
	merge m:1  activ cropgroup crop t using  "$SwissMRL/Data/mrl_data_swiss", keep(3) nogen
	merge m:1  activ cropgroup crop t using  "$SwissMRL/Data/mrl_data_codex", keep(1 3) nogen
	order country activ cropgroup crop t mrl mrl_swiss
	save "$SwissMRL/Data/mrl_data_v2", replace

do "$SwissMRL/Do files/1_CountryNames" 
do "$SwissMRL/Do files/1_ProductMatching" //*Match product names in pesticide data to 


*** Table 1: Comparison of MRLs on selected products in 2014
use "$SwissMRL/Data/mrl_data_v4", clear
 preserve
	bys activ: gen new = _N
	keep activ new 
	duplicates drop
	gsort -new
	gen count = _n
	keep if count < 101
	gen active = strproper(activ)
	keep active
replace active = active + "," //* Table A2 (100 most regulated active ingredients)
 restore 
/*preserve
	keep if t == 2018
	keep if country == "EU" | country == "USA" | country == "CAN" | country == "JPN" | country == "VNM" | country == "CHN" | country == "CODEX" 
	br if activ == "CARBARYL" 		& hs8 == "08052000"
	br if activ == "CAPTAN" 			& hs8 == "08081010"
	br if activ == "FENBUTATIN-OXIDE" & hs8 == "08081010"
	br if activ == "ACETAMIPRID" 		& hs8 == "08081010"
	br if activ == "AZOXYSTROBIN" & hs8 == "07020020"
	br if activ == "AZOXYSTROBIN" & hs8 == "07020020"
restore */
* Replacing missing values
fillin  hs8  country activ t
drop _fillin

replace mrl = mrl_codex if mrl == . & country == "ARG"
replace mrl = mrl_codex if mrl == . & country == "BRA"
replace mrl = mrl_codex if mrl == . & country == "CHL"
replace mrl = mrl_codex if mrl == . & country == "CHN"
replace mrl = mrl_codex if mrl == . & country == "EGY"
replace mrl = mrl_codex if mrl == . & country == "IND"
replace mrl = mrl_codex if mrl == . & country == "ISR"

replace mrl = 0.01 if mrl == . & country == "AUS"
replace mrl = 0.01 if mrl == . & country == "CAN"
replace mrl = 0.01 if mrl == . & country == "EU"
replace mrl = 0.01 if mrl == . & country == "JPN"
replace mrl = 0.01 if mrl == . & country == "NZL"
replace mrl = 0.01 if mrl == . & country == "NOR"
replace mrl = 0.01 if mrl == . & country == "USA"
replace mrl = 0.01 if mrl == . & country == "ARG"
replace mrl = 0.01 if mrl == . & country == "ZAF"
replace mrl = 0.01 if mrl == . & country == "ASEAN"

replace mrl_swiss = mrl if country == "EU" & mrl_swiss == . 
replace mrl_swiss = 0.01 if mrl_swiss == . 

bys hs8 activ t: egen max_mrl = max(mrl)
replace mrl = max_mrl if mrl == . 
bys hs8 activ t: egen min_mrl = min(mrl)
bys country activ hs8 t: gen mrl_ij  = exp((mrl - mrl_swiss)/mrl)
*bys         activ hs8 t: gen mrl_cod  = exp((mrl_codex - mrl_swiss)/mrl_codex)
bys country activ hs8 t: gen mrl_ro  = (mrl - mrl_swiss)/(max_mrl - min_mrl)
replace  mrl_ro = 0 if mrl_ro == .
*collapse mrl_ij mrl_swiss, by(country hs8 t)
bys country hs8 t: egen mrl_od = mean(mrl_ij)
bys         hs8 t: egen mrl_co = mean(mrl_codex)
bys country hs8 t: egen mrl_fern = mean(mrl_ro)
bys 		hs8 t: egen mrl_sw = mean(mrl_swiss)
drop activ mrl mrl_swiss mrl_codex max_mrl mrl_ij min_mrl mrl_ro
duplicates drop

save "$SwissMRL/Data/mrl_data_v5", replace 

* Duplicate EU MRLS
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
use "$SwissMRL/Data/mrl_data_v5",  clear
capture drop newobs
expand 2 if country == "EU", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_v5", replace
}
drop newobs 
drop if country == "EU"
save "$SwissMRL/Data/mrl_data_v5", replace

* Duplicate GCC MRLs
foreach x in BHR ARE SAU OMN QAT KWT{
use "$SwissMRL/Data/mrl_data_v5",  clear
capture drop newobs
expand 2 if country == "GCC", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_v5", replace
}
drop newobs 
drop if country == "GCC"
destring hs8, replace
save "$SwissMRL/Data/mrl_data_v5", replace

* GDP
import delimited "O:\Data-Work\25_Agricultural_Economics-RE\253_SupplyEvaluation\NTM\RQ2_AVE/Data/GDP.csv", varnames(1) clear
	drop if countrycode == ""
	reshape long yr, i(countryname seriesname) j(year)
	keep countrycode yr year
	rename (countrycode yr year) (iso_o gdp t)
	destring gdp, force replace 
save "$SwissMRL/Data/gdp", replace 

* Firm level import data
forvalues v = 2016(1)2018{
	import delimited "O:\Data-Work\25_Agricultural_Economics-RE\254_DemandEvaluation\EffectCoronaPrices\Gravity/Data/IMP_HS01_24_`v'_with_date.csv", varnames(1) clear
	save "$SwissMRL/Data/imports_`v'", replace 
}
	append using "$SwissMRL/Data/imports_2017"
	append using "$SwissMRL/Data/imports_2016"
	compress
	
	bys firm_uid lnd_isoc hs8 year: egen v = sum(total_imports)
	bys firm_uid lnd_isoc hs8 year: egen q = sum(total_qty)
	bys lnd_isoc hs8 year: egen mfn = mean(mfn_rate)
	keep year lnd_isoc firm_uid firm_size hs8 unit_qty unit_tariff_rate v q mfn
	duplicates drop
	replace hs8 = hs8 * 10000
	
	kountry lnd_isoc, from(iso2c) to(iso3c)
	replace _ISO3C_ = "XKX" if lnd_isoc == "XK" // Kosovo
	replace _ISO3C_ = "SGS" if lnd_isoc == "GS" // St. Georgia
	replace _ISO3C_ = "BLM" if lnd_isoc == "BL" // St. Barthelemy
	replace _ISO3C_ = "CUW" if lnd_isoc == "CW" // Curacao
	replace _ISO3C_ = "SXM" if lnd_isoc == "SX" // S. Martins
	replace _ISO3C_ = "BES" if lnd_isoc == "BQ" // Bonaire
	replace _ISO3C_ = "IOT" if lnd_isoc == "IO" // British Indian Ocean Territory
	
	rename _ISO3C_ country
	drop if country == ""
	drop lnd_isoc
	rename year t
	drop if unit_qty == "Litres"
	save "$SwissMRL/Data/import_data", replace 
	
* Export data
import delimited "$SwissFirms/Data/EXP_HS01_24_2016_2020.csv", varnames(1) clear
	kountry lnd_isoc, from(iso2c) to(iso3c)
	replace _ISO3C_ = "XKX" if lnd_isoc == "XK" // Kosovo
	replace _ISO3C_ = "SGS" if lnd_isoc == "GS" // St. Georgia
	replace _ISO3C_ = "BLM" if lnd_isoc == "BL" // St. Barthelemy
	replace _ISO3C_ = "CUW" if lnd_isoc == "CW" // Curacao
	replace _ISO3C_ = "SXM" if lnd_isoc == "SX" // S. Martins
	replace _ISO3C_ = "BES" if lnd_isoc == "BQ" // Bonaire
	replace _ISO3C_ = "IOT" if lnd_isoc == "IO" // British Indian Ocean Territory
	
	rename year t

	rename uid firm_uid 
	bys firm_uid t: egen export = sum(total_value_chf)
	keep firm_uid t export
	duplicates drop 
	save "$SwissMRL/Data/export_data", replace
/*foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
replace country = "EU" if country == "`x'"
}
foreach x in BRN KHM IDN LAO MYS MMR PHL SGP THA VNM{
replace country = "ASEAN" if country == "`x'"
}
foreach x in BHR ARE SAU OMN QAT KWT{
replace country = "GCC" if country == "`x'"
}

bys firm_uid country hs8 t: egen v_s = sum(v)
bys firm_uid country hs8 t: egen q_s = sum(q)
bys firm_uid country hs8 t: egen mfn_s = mean(mfn)
drop v q mfn
duplicates drop */

use "$SwissMRL/Data/import_data", clear
	merge m:1 country hs8 t using "$SwissMRL/Data/mrl_data_v5", keep(3) nogen
	merge m:1 firm_uid t using "$SwissMRL/Data/export_data", keep(1 3) nogen
	gen iso_d = "CHE"
	rename country iso_o
	merge m:1 iso_o iso_d using "$SwissNTM\Data\dist_cepii",   keep(1 3) nogen
	merge m:1 iso_o iso_d t using "$SwissNTM\Data\rta_20200520", keep(1 3) nogen
	merge m:1 iso_o  t using "$SwissMRL/Data/gdp", keep(1 3) nogen

	*merge m:1 country hs6 t using "$SwissMRL/Data/ntm", keep( 1 3) nogen
	
	drop mrl_co mrl_fern mrl_sw colony comcol curcol col45 smctry dist distw distwces cu fta psa eia cueia ftaeia psaeia
	compress
	save "$SwissMRL/Data/mrl_data_v6", replace
	 
*use "O:\Data-Work\25_Agricultural_Economics-RE\253_SupplyEvaluation\NTM\RQ2_AVE\Data\NTM Data\ntm.dta"

*save "$SwissMRL/Data/ntm"

/*rename country iso_o
gen iso_d = "CHE"
merge m:1 iso_o iso_d using "$SwissNTM\Data\dist_cepii",   keep(1 3) nogen
merge m:1 iso_o iso_d t using "$SwissNTM\Data\rta_20200520", keep(1 3) nogen
merge m:1 iso_o  t using "$SwissMRL/Data/gdp", keep(1 3) nogen
rename iso_o country*/

*drop iso_d
*rename iso_o country

/*
use "$SwissMRL/Data/mrl_data", clear
destring hs8, force replace 
drop cropgroup crop
duplicates drop 
merge m:m country hs8 t using "$SwissMRL/Data/import_data"

forvalues v = 2016(1)2020{
	erase "$SwissMRL/Data/imports_`v'.dta"
}

*keep crop 
*duplicates drop 
*save "$SwissMRL/Data/mrl_data_temp", replace
*use "$SwissMRL/Data/mrl_data_temp", clear

*br if t == 2016 
*keep if country == "SWITZERLAND"

*keep if activ == "2.4-D" | activ == "ABAMECTIN" | activ == "ACEQUINOCYL" | activ == "ACETAMIPRID" | activ == "ACIBENZOLAR-S-M" | activ == "ACLONIFEN" | activ == "AMETOCTRADIN" /// 
*	 if activ == "AMIDOSULFURON" | activ == "AMINOPYRALID" | activ == "AMISULBROM" | activ == "ASULAM" | activ == "AZADIRACHTIN" |activ == "AZOXYSTROBIN" | 

* 2.4-DB
* 2.4-DP
* 2.4-DP-P
* 2.4.5-T

*/

use "$SwissMRL/Data/mrl_data_v4",  clear

drop if mrl_codex == . 
fillin  hs8  country activ t
drop _fillin

replace mrl = mrl_codex if mrl == . & country == "ARG"
replace mrl = mrl_codex if mrl == . & country == "BRA"
replace mrl = mrl_codex if mrl == . & country == "CHL"
replace mrl = mrl_codex if mrl == . & country == "CHN"
replace mrl = mrl_codex if mrl == . & country == "EGY"
replace mrl = mrl_codex if mrl == . & country == "IND"
replace mrl = mrl_codex if mrl == . & country == "ISR"

replace mrl = 0.01 if mrl == . & country == "AUS"
replace mrl = 0.01 if mrl == . & country == "CAN"
replace mrl = 0.01 if mrl == . & country == "EU"
replace mrl = 0.01 if mrl == . & country == "JPN"
replace mrl = 0.01 if mrl == . & country == "NZL"
replace mrl = 0.01 if mrl == . & country == "NOR"
replace mrl = 0.01 if mrl == . & country == "USA"
replace mrl = 0.01 if mrl == . & country == "ARG"
replace mrl = 0.01 if mrl == . & country == "ZAF"
replace mrl = 0.01 if mrl == . & country == "ASEAN"

replace mrl_swiss = mrl if country == "EU" & mrl_swiss == . 
replace mrl_swiss = 0.01 if mrl_swiss == .

drop if mrl_codex == . 

bys	activ hs8 t: gen mrl_co  = exp((mrl_codex - mrl_swiss)/mrl_codex)
bys       hs8 t: egen mrl_cod = mean(mrl_co)
drop activ mrl_swiss mrl_codex mrl_co  mrl
duplicates drop

save "$SwissMRL/Data/mrl_data_codex", replace 

* Duplicate EU MRLS
foreach x in AUT BEL CZE DNK EST FIN FRA GRC HUN IRL ITA LVA LTU LUX POL PRT SVK SVN ESP SWE GBR MLT DEU NLD CYP BGR HRV ROU{
use "$SwissMRL/Data/mrl_data_codex",  clear
capture drop newobs
expand 2 if country == "EU", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_codex", replace
}
drop newobs 
drop if country == "EU"
save "$SwissMRL/Data/mrl_data_codex", replace

* Duplicate GCC MRLs
foreach x in BHR ARE SAU OMN QAT KWT{
use "$SwissMRL/Data/mrl_data_codex",  clear
capture drop newobs
expand 2 if country == "GCC", gen(newobs)
replace country = "`x'" if newobs == 1
save "$SwissMRL/Data/mrl_data_codex", replace
}
drop newobs 
drop if country == "GCC"
destring hs8, replace
save "$SwissMRL/Data/mrl_data_codex", replace

use "$SwissMRL/Data/import_data", clear
	merge m:1 country hs8 t using "$SwissMRL/Data/mrl_data_codex", keep(3) nogen
	merge m:1 firm_uid t using "$SwissMRL/Data/export_data", keep(1 3) nogen
	gen iso_d = "CHE"
	rename country iso_o
	merge m:1 iso_o iso_d using "$SwissNTM\Data\dist_cepii",   keep(1 3) nogen
	merge m:1 iso_o iso_d t using "$SwissNTM\Data\rta_20200520", keep(1 3) nogen
	merge m:1 iso_o  t using "$SwissMRL/Data/gdp", keep(1 3) nogen
	
save "$SwissMRL/Data/mrl_data_codex", replace 

forvalues v = 2016(1)2018{
	erase "$SwissMRL/Data/imports_`v'.dta"
}
forvalues v = 2016(1)2018{
	erase "$SwissMRL/Data/MRL`v'.dta"
}
erase "$SwissMRL/Data/mrl_data.dta"
erase "$SwissMRL/Data/mrl_data_swiss.dta"
erase "$SwissMRL/Data/mrl_data_v2.dta"
erase "$SwissMRL/Data/mrl_data_v3.dta"
erase "$SwissMRL/Data/mrl_data_v4.dta"
*erase "$SwissMRL/Data/mrl_data_v5.dta"


foreach v in ASEAN codex eu IDN KHM LAO MMR MYS PHL SGP THA VNM TLS{
	erase "$SwissMRL/Data/MRL_data_`v'.dta"
}